import os
import logging.handlers
from jiange.file import dump_json


class LogAgent():

    def __init__(self):
        self.logger = self.init_log()

    def info(self, body):
        """支持对 str / dict 类型的数据记录日志"""
        if isinstance(body, dict):
            body = dump_json(body, indent=False)
        self.logger.info(body)

    @staticmethod
    def init_log():
        """
        - 日志采用 RotatingFileHandler 方式存储，单个文件最大 5M
        - 存储路径 /tmp/logs/，并以 log.txt, log.txt.1, ... 命名
        """
        path_tgt = '/tmp/logs'
        if not os.path.exists(path_tgt):
            os.mkdir(path_tgt)
        log_file = os.path.join(path_tgt, 'log.txt')
        log_level = logging.INFO
        logger = logging.getLogger("loggingmodule.NomalLogger")
        handler = logging.handlers.RotatingFileHandler(log_file, maxBytes=1024 * 1024 * 5, backupCount=10, encoding='utf8')
        formatter = logging.Formatter("[%(levelname)s][%(filename)s][%(asctime)s]%(message)s")
        handler.setFormatter(formatter)
        logger.addHandler(handler)
        logger.setLevel(log_level)
        return logger



from jiange.log import LogAgent
from jiange.file import dump_json


class AgentBase(object):

    def __init__(self, *args, **kwargs):
        self.skill_name = None
        self.log = LogAgent()

    def dispatch(self, *args, **kwargs):
        raise NotImplementedError

    def response(self, *args, **kwargs):
        """

        e.g.
        response = {
            'code': 200,
            'message': 'success',
            'data': {
                'output': output,
                'skill_name': self.skill_name
            }
        }
        """
        raise NotImplementedError

    def log_request_response(self, request, response):
        body = {
            'request': request,
            'response': response,
            'skill_name': self.skill_name
        }
        body = dump_json(body, indent=False)
        self.log.info(body)

    def log_info(self, body):
        if isinstance(body, dict):
            body = dump_json(body, indent=False)
        self.log.info(body)



from setuptools import setup


VERSION = 'v0.1.8'

requirements = '''
certifi==2022.6.15
charset-normalizer==2.1.0
idna==3.3
pyahocorasick==1.4.4
requests
tqdm==4.64.0
urllib3==1.26.11
xlrd==1.2.0
XlsxWriter==3.0.3
'''
install_requires = [x.strip() for x in requirements.split('\n') if x.strip()]

setup(
    name='jiange',
    version=VERSION[1:],
    description='functions to save your life',
    url='http://github.com/linjianz',
    author='Zhang Linjian',
    author_email='zhanglinjian1@gmail.com',
    license='MIT',
    packages=['jiange'],
    install_requires=install_requires,
    zip_safe=False)
